locals {
  # This is a workaround for not having this variable in the team cluster.
  # Metrics will fail in the team cluster, but the job will succeed.
  wavefront_url = "https://sbu.wavefront.com"

  cmdline_config         = jsondecode(var.extra_environment.JOB_CONFIG_CMDLINE)
  filepath_config        = jsondecode(var.extra_environment.JOB_CONFIG_FILEPATH)
  sha256_config          = jsondecode(var.extra_environment.JOB_CONFIG_SHA256)
  filepath_sha256_config = jsondecode(var.extra_environment.JOB_CONFIG_FILEPATH_SHA256)
}

data "aws_iam_role" "job_role" {
  name = var.iam_role_name
}

module "mdr_prevalence_cmdline" {
  source = "./modules/mdr-prevalence"
  tags   = var.tags
  env    = var.extra_environment.ENV_NAME

  aggregation_name   = "cmdline"
  job_config_hourly  = local.cmdline_config.hourly
  job_config_daily   = local.cmdline_config.daily
  job_config_24hours = local.cmdline_config.rolling_24hours
  job_config_31days  = local.cmdline_config.rolling_31day

  default_mdr_lib_version     = var.default_mdr_lib_version
  tools_bucket_name           = var.tools_bucket_name
  data_bucket_name            = var.data_bucket_name
  processing_bucket_name      = var.processing_bucket_name
  database_name               = var.database_name
  security_configuration_name = aws_glue_security_configuration.mdr_prevalence.name
  job_role_arn                = data.aws_iam_role.job_role.arn
  athena_workgroup_name       = var.athena_workgroup_name
  src_tbl_name                = var.extra_environment.SRC_TABLE_NAME
  src_account_id              = var.extra_environment.SRC_ACCOUNT_ID
  name_prefix                 = var.name_prefix
  wavefront_url               = local.wavefront_url
  mcs2_env                    = var.mcs2_env
}

module "mdr_prevalence_filepath" {
  source = "./modules/mdr-prevalence"
  tags   = var.tags
  env    = var.extra_environment.ENV_NAME

  aggregation_name   = "filepath"
  job_config_hourly  = local.filepath_config.hourly
  job_config_daily   = local.filepath_config.daily
  job_config_24hours = local.filepath_config.rolling_24hours
  job_config_31days  = local.filepath_config.rolling_31day

  default_mdr_lib_version     = var.default_mdr_lib_version
  tools_bucket_name           = var.tools_bucket_name
  data_bucket_name            = var.data_bucket_name
  processing_bucket_name      = var.processing_bucket_name
  database_name               = var.database_name
  security_configuration_name = aws_glue_security_configuration.mdr_prevalence.name
  job_role_arn                = data.aws_iam_role.job_role.arn
  athena_workgroup_name       = var.athena_workgroup_name
  src_tbl_name                = var.extra_environment.SRC_TABLE_NAME
  src_account_id              = var.extra_environment.SRC_ACCOUNT_ID
  name_prefix                 = var.name_prefix
  wavefront_url               = local.wavefront_url
  mcs2_env                    = var.mcs2_env
}

module "mdr_prevalence_sha256" {
  source = "./modules/mdr-prevalence"
  tags   = var.tags
  env    = var.extra_environment.ENV_NAME

  aggregation_name   = "sha256"
  job_config_hourly  = local.sha256_config.hourly
  job_config_daily   = local.sha256_config.daily
  job_config_24hours = local.sha256_config.rolling_24hours
  job_config_31days  = local.sha256_config.rolling_31day

  default_mdr_lib_version     = var.default_mdr_lib_version
  tools_bucket_name           = var.tools_bucket_name
  data_bucket_name            = var.data_bucket_name
  processing_bucket_name      = var.processing_bucket_name
  database_name               = var.database_name
  security_configuration_name = aws_glue_security_configuration.mdr_prevalence.name
  job_role_arn                = data.aws_iam_role.job_role.arn
  athena_workgroup_name       = var.athena_workgroup_name
  src_tbl_name                = var.extra_environment.SRC_TABLE_NAME
  src_account_id              = var.extra_environment.SRC_ACCOUNT_ID
  name_prefix                 = var.name_prefix
  wavefront_url               = local.wavefront_url
  mcs2_env                    = var.mcs2_env
}

module "mdr_prevalence_filepath_sha256" {
  source = "./modules/mdr-prevalence"
  tags   = var.tags
  env    = var.extra_environment.ENV_NAME

  aggregation_name    = "filepath-sha256"
  glue_handler_prefix = local.filepath_sha256_config.glue_handler_prefix # this variable is needed only for combo jobs
  combo_job_map       = local.filepath_sha256_config.combo_job_map       # needed only for combo jobs
  job_config_hourly   = local.filepath_sha256_config.hourly
  job_config_daily    = local.filepath_sha256_config.daily
  job_config_24hours  = local.filepath_sha256_config.rolling_24hours
  job_config_31days   = local.filepath_sha256_config.rolling_31day

  default_mdr_lib_version     = var.default_mdr_lib_version
  tools_bucket_name           = var.tools_bucket_name
  data_bucket_name            = var.data_bucket_name
  processing_bucket_name      = var.processing_bucket_name
  database_name               = var.database_name
  security_configuration_name = aws_glue_security_configuration.mdr_prevalence.name
  job_role_arn                = data.aws_iam_role.job_role.arn
  athena_workgroup_name       = var.athena_workgroup_name
  src_tbl_name                = var.extra_environment.SRC_TABLE_NAME
  src_account_id              = var.extra_environment.SRC_ACCOUNT_ID
  name_prefix                 = var.name_prefix
  wavefront_url               = local.wavefront_url
  mcs2_env                    = var.mcs2_env
}
